# quac

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Developer Guide

### Setup

``` sh
# create conda environment
$ mamba env create -f env.yml

# update conda environment
$ mamba env update -n quac --file env.yml
```

### Install

``` sh
pip install -e .

# install from pypi
pip install quac
```

### nbdev

``` sh
# activate conda environment
$ conda activate quac

# make sure the quac package is installed in development mode
$ pip install -e .

# make changes under nbs/ directory
# ...

# compile to have changes apply to the quac package
$ nbdev_prepare
```

### Publishing

``` sh
# publish to pypi
$ nbdev_pypi

# publish to conda
$ nbdev_conda --build_args '-c conda-forge'
$ nbdev_conda --mambabuild --build_args '-c conda-forge -c dsm-72'
```

# Usage

## Installation

Install latest from the GitHub
[repository](https://github.com/dsm-72/quac):

``` sh
$ pip install git+https://github.com/dsm-72/quac.git
```

or from [conda](https://anaconda.org/dsm-72/quac)

``` sh
$ conda install -c dsm-72 quac
```

or from [pypi](https://pypi.org/project/quac/)

``` sh
$ pip install quac
```

## Documentation

Documentation can be found hosted on GitHub
[repository](https://github.com/dsm-72/quac)
[pages](https://dsm-72.github.io/quac/). Additionally you can find
package manager specific guidelines on
[conda](https://anaconda.org/dsm-72/quac) and
[pypi](https://pypi.org/project/quac/) respectively.
